@@ -279,4 +279,11 @@ def Predict(param, model, gen, BB_output_folder, names, true_pred = None, true_p
         if param['save_to_npy']:
             SaveMatrix(BB_output_folder,names[k],image_dict,images_to_save)
         
-    return list(SEG),list(areas) # return Jacard indicees for each 
\ No newline at end of file
+    if not SEG is None:
+        SEG = list(SEG)
+    if not areas is None:
+        areas = list(areas)
+
+    return SEG, areas # return Jacard indicees for each 
+
+
